@@ -51,22 +51,6 @@ module Aruba
         setup_aruba
       end
 
-      # @deprecated
-      # Execute block in current directory
-      #
-      # @yield
-      #   The block which should be run in current directory
-      def in_current_directory(&block)
-        Aruba.platform.deprecated(
-          'The use of "in_current_directory" is deprecated.' \
-          ' Use "#cd(\'.\') { # your code }" instead. But be aware,' \
-          ' "cd" requires a previously created directory'
-        )
-
-        create_directory '.' unless directory?('.')
-        cd('.', &block)
-      end
-
       # @deprecated
       def detect_ruby(cmd)
         Aruba.platform.deprecated('The use of "#detect_ruby" is deprecated')
@@ -525,11 +509,10 @@ module Aruba
       def in_current_dir(&block)
         Aruba.platform.deprecated(
           'The use of "in_current_dir" is deprecated.' \
-          ' Use "#cd(\'.\') { }" instead'
+          ' Use "#in_current_directory { }" instead'
         )
 
-        create_directory '.' unless directory?('.')
-        cd('.', &block)
+        in_current_directory(&block)
       end
 
       # @deprecated
@@ -791,8 +774,7 @@ module Aruba
       def assert_partial_output(expected, actual)
         Aruba.platform.deprecated(
           'The use of "#assert_partial_output" is deprecated.' \
-          ' Use "expect(command).to have_output /partial/" instead.' \
-          ' There are also special matchers for "stdout" and "stderr"'
+          ' Use "expect(actual).to include_output_string partial" instead.'
         )
 
         actual.force_encoding(expected.encoding) if RUBY_VERSION >= "1.9"
@@ -809,8 +791,7 @@ module Aruba
       def assert_matching_output(expected, actual)
         Aruba.platform.deprecated(
           'The use of "#assert_matching_output" is deprecated.' \
-          ' Use "expect(command).to have_output /partial/" instead.' \
-          ' There are also special matchers for "stdout" and "stderr"'
+          ' Use "expect(actual).to match_output partial" instead.'
         )
 
         actual.force_encoding(expected.encoding) if RUBY_VERSION >= "1.9"
@@ -827,8 +808,7 @@ module Aruba
       def assert_not_matching_output(expected, actual)
         Aruba.platform.deprecated(
           'The use of "#assert_not_matching_output" is deprecated.' \
-          ' Use "expect(command).not_to have_output /partial/" instead.' \
-          ' There are also special matchers for "stdout" and "stderr"'
+          ' Use "expect(actual).not_to match_output partial" instead.'
         )
 
         actual.force_encoding(expected.encoding) if RUBY_VERSION >= "1.9"
@@ -845,8 +825,7 @@ module Aruba
       def assert_no_partial_output(unexpected, actual)
         Aruba.platform.deprecated(
           'The use of "#assert_no_partial_output" is deprecated.' \
-          ' Use "expect(command).not_to have_output /partial/" instead.' \
-          ' There are also special matchers for "stdout" and "stderr"'
+          ' Use "expect(actual).not_to include_output_string partial" instead.'
         )
 
         actual.force_encoding(unexpected.encoding) if RUBY_VERSION >= "1.9"
@@ -868,8 +847,7 @@ module Aruba
       def assert_partial_output_interactive(expected)
         Aruba.platform.deprecated(
           'The use of "#assert_partial_output_interactive" is deprecated.' \
-          ' Use "expect(last_command_started).to have_output /partial/" instead.' \
-          ' There are also special matchers for "stdout" and "stderr"'
+          ' Use "expect(last_command_started).to have_output an_output_string_including partial" instead.'
         )
 
         Aruba.platform.unescape(last_command_started.stdout, aruba.config.keep_ansi).
@@ -1017,66 +995,9 @@ module Aruba
         process_monitor.stderr_from(cmd)
       end
 
-      # @deprecated
-      #
-      # Get stdout of all processes
-      #
-      # @return [String]
-      #   The stdout of all process which have run before
-      def all_stdout
-        Aruba.platform.deprecated(
-          'The use of "#all_stdout" is deprecated.' \
-          ' Use `all_commands.map { |c| c.stdout }.join("\n") instead.' \
-          ' If you need to check for some output, use' \
-          ' "expect(all_commands).to included_an_object have_output_on_stdout(/output/)"' \
-          ' instead'
-        )
-
-        process_monitor.all_stdout
-      end
-
-      # @deprecated
-      #
-      # Get stderr of all processes
-      #
-      # @return [String]
-      #   The stderr of all process which have run before
-      def all_stderr
-        Aruba.platform.deprecated(
-          'The use of "#all_stderr" is deprecated.' \
-          ' Use `all_commands.map { |c| c.stderr }.join("\n") instead.' \
-          ' If you need to check for some output use' \
-          ' "expect(all_commands).to included_an_object have_output_on_stderr /output/"' \
-          ' instead'
-        )
-
-        process_monitor.all_stderr
-      end
-
-      # @deprecated
-      #
-      # Get stderr and stdout of all processes
-      #
-      # @return [String]
-      #   The stderr and stdout of all process which have run before
-      def all_output
-        Aruba.platform.deprecated(
-          'The use of "#all_output" is deprecated.' \
-          ' Use `all_commands.map { |c| c.output }.join("\n") instead.' \
-          ' If you need to check for some output use' \
-          ' "expect(all_commands).to included_an_object have_output /output/"' \
-          ' instead'
-        )
-
-        process_monitor.all_output
-      end
-
       # @deprecated
       #
       # Default exit timeout for running commands with aruba
-      #
-      # Overwrite this method if you want a different timeout or set
-      # `@aruba_timeout_seconds`.
       def exit_timeout
         Aruba.platform.deprecated(
           'The use of "#exit_timeout" is deprecated.' \
