@@ -44,12 +44,6 @@ Before('@announce-command-filesystem-status') do
   aruba.announcer.activate :command_filesystem_status
 end
 
-Before('@announce-cmd') do
-  Aruba.platform.deprecated 'The use of "@announce-cmd"-hook is deprecated. Please use "@announce-command"'
-
-  aruba.announcer.activate :command
-end
-
 Before('@announce-output') do
   aruba.announcer.activate :stdout
   aruba.announcer.activate :stderr
@@ -63,12 +57,6 @@ Before('@announce-stderr') do
   aruba.announcer.activate :stderr
 end
 
-Before('@announce-dir') do
-  Aruba.platform.deprecated 'The use of "@announce-dir"-hook is deprecated. Please use "@announce-directory"'
-
-  aruba.announcer.activate :directory
-end
-
 Before('@announce-directory') do
   aruba.announcer.activate :directory
 end
@@ -77,28 +65,10 @@ Before('@announce-stop-signal') do
   aruba.announcer.activate :stop_signal
 end
 
-Before('@announce-env') do
-  Aruba.platform.deprecated 'The use of "@announce-env"-hook is deprecated. Please use "@announce-changed-environment"'
-
-  aruba.announcer.activate :environment
-end
-
-Before('@announce-environment') do
-  Aruba.platform.deprecated '@announce-environment is deprecated. Use @announce-changed-environment instead'
-
-  aruba.announcer.activate :changed_environment
-end
-
 Before('@announce-full-environment') do
   aruba.announcer.activate :full_environment
 end
 
-Before('@announce-modified-environment') do
-  Aruba.platform.deprecated '@announce-modified-environment is deprecated. Use @announce-changed-environment instead'
-
-  aruba.announcer.activate :changed_environment
-end
-
 Before('@announce-changed-environment') do
   aruba.announcer.activate :changed_environment
 end
@@ -135,25 +105,11 @@ end
 #   aruba.config.command_launcher = :spawn
 # end
 
-Before('@ansi') do
-  # rubocop:disable Metrics/LineLength
-  Aruba::Platform.deprecated('The use of "@ansi" is deprecated. Use "@keep-ansi-escape-sequences" instead. But be aware, that this hook uses the aruba configuration and not an instance variable')
-  # rubocop:enable Metrics/LineLength
-
-  aruba.config.remove_ansi_escape_sequences = false
-end
-
 Before('@keep-ansi-escape-sequences') do
   aruba.config.remove_ansi_escape_sequences = false
   aruba.config.keep_ansi = true
 end
 
-Before '@mocked_home_directory' do
-  Aruba.platform.deprecated('The use of "@mocked_home_directory" is deprecated. Use "@mocked-home-directory" instead')
-
-  set_environment_variable 'HOME', expand_path('.')
-end
-
 Before '@mocked-home-directory' do
   set_environment_variable 'HOME', expand_path('.')
 end
