@@ -2,7 +2,7 @@ require 'rspec/expectations/version'
 
 require 'fileutils'
 
-# @!method have_same_file_content_like(file_name)
+# @!method have_same_file_content_as(file_name)
 #   This matchers checks if <file1> has the same content like <file2>
 #
 #   @param [String] file_name
@@ -19,10 +19,10 @@ require 'fileutils'
 #   @example Use matcher
 #
 #     RSpec.describe do
-#       it { expect(file1).to have_same_file_content_like(file2) }
-#       it { expect(files).to include a_file_with_same_content_like(file2) }
+#       it { expect(file1).to have_same_file_content_as(file2) }
+#       it { expect(files).to include a_file_with_same_content_as(file2) }
 #     end
-RSpec::Matchers.define :have_same_file_content_like do |expected|
+RSpec::Matchers.define :have_same_file_content_as do |expected|
   match do |actual|
     stop_all_commands
 
@@ -44,5 +44,5 @@ RSpec::Matchers.define :have_same_file_content_like do |expected|
 end
 
 if RSpec::Expectations::Version::STRING >= '3.0'
-  RSpec::Matchers.alias_matcher :a_file_with_same_content_like, :have_same_file_content_like
+  RSpec::Matchers.alias_matcher :a_file_with_same_content_as, :have_same_file_content_as
 end
