@@ -10,13 +10,9 @@ module Aruba
     #
     # @private
     class WindowsCommandString < SimpleDelegator
-      def initialize(cmd)
-        __setobj__ format('%s /c "%s"', Aruba.platform.which('cmd.exe'), cmd)
-      end
-
       # Convert to array
       def to_a
-        Shellwords.split __getobj__
+        [cmd_path, '/c', __getobj__]
       end
 
       if RUBY_VERSION < '1.9'
@@ -25,6 +21,12 @@ module Aruba
         end
         alias inspect to_s
       end
+
+      private
+
+      def cmd_path
+        Aruba.platform.which('cmd.exe')
+      end
     end
   end
 end
